You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by lu...@apache.org on 2012/08/17 09:15:06 UTC

svn commit: r1374161 - /commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/DerivativeStructure.java

Author: luc
Date: Fri Aug 17 07:15:05 2012
New Revision: 1374161

URL: http://svn.apache.org/viewvc?rev=1374161&view=rev
Log:
Changed parameters name for consistency with getters and DSCompiler.

Modified:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/DerivativeStructure.java

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/DerivativeStructure.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/DerivativeStructure.java?rev=1374161&r1=1374160&r2=1374161&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/DerivativeStructure.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/DerivativeStructure.java Fri Aug 17 07:15:05 2012
@@ -70,21 +70,22 @@ public class DerivativeStructure impleme
     }
 
     /** Build an instance with all values and derivatives set to 0.
      * @param variables number of variables
      * @param order derivation order
      */
-    public DerivativeStructure(final int variables, final int order) {
-        this(DSCompiler.getCompiler(variables, order));
+    public DerivativeStructure(final int parameters, final int order) {
+        this(DSCompiler.getCompiler(parameters, order));
     }
 
     /** Build an instance representing a constant value.
      * @param variables number of variables
      * @param order derivation order
      * @param value value of the constant
      * @see #DerivativeStructure(int, int, int, double)
      */
-    public DerivativeStructure(final int variables, final int order, final double value) {
-        this(variables, order);
+    public DerivativeStructure(final int parameters, final int order, final double value) {
+        this(parameters, order);
         this.data[0] = value;
     }
 
@@ -93,20 +94,20 @@ public class DerivativeStructure impleme
      * to be the free variables with respect to which differentials
      * are computed. As such, their differential with respect to
      * themselves is +1.</p>
      * @param variables number of variables
      * @param order derivation order
      * @param index index of the variable (from 0 to {@code variables - 1})
      * @param value value of the variable
      * @exception NumberIsTooLargeException if index is equal to variables or larger
      * @see #DerivativeStructure(int, int, double)
      */
-    public DerivativeStructure(final int variables, final int order,
+    public DerivativeStructure(final int parameters, final int order,
                                final int index, final double value)
         throws NumberIsTooLargeException {
-        this(variables, order, value);
+        this(parameters, order, value);
 
-        if (index >= variables) {
-            throw new NumberIsTooLargeException(index, variables, false);
+        if (index >= parameters) {
+            throw new NumberIsTooLargeException(index, parameters, false);
         }
 
         if (order > 0) {
@@ -70,21 +70,22 @@ public class DerivativeStructure impleme
 
     /** Build an instance with all values and derivatives set to 0.
-     * @param variables number of variables
+     * @param parameters number of free parameters
      * @param order derivation order
      */
@@ -70,21 +70,22 @@ public class DerivativeStructure impleme
 
     /** Build an instance representing a constant value.
-     * @param variables number of variables
+     * @param parameters number of free parameters
+     * @param parameters number of variables
      * @param order derivation order
      * @param value value of the constant
@@ -93,20 +94,20 @@ public class DerivativeStructure impleme
      * are computed. As such, their differential with respect to
      * themselves is +1.</p>
-     * @param variables number of variables
+     * @param parameters number of free parameters
      * @param order derivation order
      * @param index index of the variable (from 0 to {@code variables - 1})